Crate zoneinfo_db

Crate zoneinfo_db 

Rust parser of ZoneInfoDb(tzdata) on Android and OpenHarmony

Ported from: https://android.googlesource.com/platform/prebuilts/fullsdk/sources/+/refs/heads/androidx-appcompat-release/android-34/com/android/i18n/timezone/ZoneInfoDb.java

Structs

TzDataHeader
Header of the tzdata file.
TzDataIndex
Index entry of the tzdata file.
TzDataIndexes
Indexes of the tzdata file.

Functions

find_tz_data_android
Get timezone data from the tzdata file reader of Android.
find_tz_data_android_from_fs
Get timezone data from the tzdata file of Android.
find_tz_data_ohos
Get timezone data from the tzdata file reader of HarmonyOS NEXT.
find_tz_data_ohos_from_fs
Get timezone data from the tzdata file of HarmonyOS NEXT.