TzDataIndexes

Struct TzDataIndexes 

pub struct TzDataIndexes { /* private fields */ }
Indexes of the tzdata file.

Implementations

Source

impl TzDataIndexes

pub fn new_android<R: Read>(reader: R, header: &TzDataHeader) -> Result<Self>

Parse the indexes of the tzdata file of Android.

pub fn new_ohos<R: Read>(reader: R, header: &TzDataHeader) -> Result<Self>

Parse the indexes of the tzdata file of HarmonyOS NEXT.

pub fn timezones(&self) -> &[TzDataIndex]

Get all timezones.

pub fn find_timezone(&self, timezone: &[u8]) -> Option<&TzDataIndex>

Find a timezone by name.

pub fn find_tzdata<R: Read + Seek>( &self, reader: R, header: &TzDataHeader, index: &TzDataIndex, ) -> Result<Vec<u8>>

Retrieve a chunk of timezone data by the index.